Package: aroma.cn
Version: 1.7.1
Depends: R (>= 3.1.2), R.utils (>= 2.11.0), aroma.core (>= 3.2.2)
Imports: R.methodsS3 (>= 1.8.1), R.oo (>= 1.24.0), R.filesets (>=
        2.14.0), R.cache (>= 0.15.0), matrixStats (>= 0.61.0), PSCBS
        (>= 0.65.0), future.apply
Suggests: aroma.light (>= 2.2.1), DNAcopy (>= 1.40.0), GLAD (>= 1.12.0)
SuggestsNote: BioC (>= 3.0), Recommended: aroma.light, DNAcopy
Title: Copy-Number Analysis of Large Microarray Data Sets
Authors@R: c(
  person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                 email="henrikb@braju.com"),
  person("Pierre", "Neuvial", role="aut"))
Description: Methods for analyzing DNA copy-number data.  Specifically,
  this package implements the multi-source copy-number normalization (MSCN)
  method for normalizing copy-number data obtained on various platforms and
  technologies.  It also implements the TumorBoost method for normalizing
  paired tumor-normal SNP data.
License: LGPL (>= 2.1)
LazyLoad: TRUE
biocViews: ProprietaryPlatforms, aCGH, CopyNumberVariants, SNP,
        Microarray, OneChannel, TwoChannel, DataImport,
        DataRepresentation, Preprocessing, QualityControl
URL: https://www.aroma-project.org/,
        https://github.com/HenrikBengtsson/aroma.cn
BugReports: https://github.com/HenrikBengtsson/aroma.cn/issues
NeedsCompilation: no
Packaged: 2024-02-17 19:57:52 UTC; henrik
Author: Henrik Bengtsson [aut, cre, cph],
  Pierre Neuvial [aut]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2024-02-17 20:30:02 UTC
Built: R 4.6.0; ; 2026-04-28 14:15:01 UTC; unix
